@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_memory.c 12371 2013-10-21 11:12:43Z fwobbe $
+ *	$Id: gmt_memory.c 12857 2014-02-06 00:26:26Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2014 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -67,7 +67,7 @@ void GMT_memtrack_off (struct GMT_CTRL *GMT)
 	GMT->hidden.mem_keeper->active = false;
 }
 
-static inline double gmt_memtrack_mem (struct GMT_CTRL *GMT, size_t mem, unsigned int *unit) {
+static inline double gmt_memtrack_mem (size_t mem, unsigned int *unit) {
 	/* Report the memory in the chosen unit */
 	unsigned int k = 0;
 	double val = mem / 1024.0;	/* Kb */
@@ -316,7 +316,7 @@ static inline bool gmt_memtrack_sub (struct GMT_CTRL *GMT, const char *where, vo
 static inline void gmt_treereport (struct GMT_CTRL *GMT, struct MEMORY_ITEM *x) {
 	unsigned int u;
 	char *unit[3] = {"kb", "Mb", "Gb"};
-	double size = gmt_memtrack_mem (GMT, x->size, &u);
+	double size = gmt_memtrack_mem (x->size, &u);
 	struct MEMORY_TRACKER *M = GMT->hidden.mem_keeper;
 	GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Memory not freed first allocated in %s (ID = %" PRIuS "): %.3f %s [%" PRIuS " bytes]\n", x->name, x->ID, size, unit[u], x->size);
 	if (M->do_log)
@@ -347,19 +347,19 @@ void GMT_memtrack_report (struct GMT_CTRL *GMT) {
 		n_multi_frees = M->n_freed - M->n_allocated;
 	/* Only insist on report if a leak or multi free, otherwise requires -V: */
 	level = (excess || n_multi_frees) ? GMT_MSG_NORMAL : GMT_MSG_VERBOSE;
-	size = gmt_memtrack_mem (GMT, M->maximum, &u);
+	size = gmt_memtrack_mem (M->maximum, &u);
 	GMT_Report (GMT->parent, level, "Max total memory allocated was %.3f %s [%" PRIuS " bytes]\n",
 							size, unit[u], M->maximum);
 		if (M->do_log)
 			fprintf (M->fp, "# Max total memory allocated was %.3f %s [%"
 							 PRIuS " bytes]\n", size, unit[u], M->maximum);
-	size = gmt_memtrack_mem (GMT, M->largest, &u);
+	size = gmt_memtrack_mem (M->largest, &u);
 	GMT_Report (GMT->parent, level, "Single largest allocation was %.3f %s [%" PRIuS " bytes]\n", size, unit[u], M->largest);
 		if (M->do_log)
 			fprintf (M->fp, "# Single largest allocation was %.3f %s [%"
 							 PRIuS " bytes]\n", size, unit[u], M->largest);
 	if (M->current) {
-		size = gmt_memtrack_mem (GMT, M->current, &u);
+		size = gmt_memtrack_mem (M->current, &u);
 		GMT_Report (GMT->parent, level, "MEMORY NOT FREED: %.3f %s [%" PRIuS " bytes]\n",
 								size, unit[u], M->current);
 		if (M->do_log)
@@ -421,6 +421,7 @@ void gmt_init_tmp_arrays (struct GMT_CTRL *GMT, size_t n_cols)
 	for (col = 0; col < n_cols; col++)	/* For each column, reallocate space for n_rows */
 		GMT->hidden.mem_coord[col] = GMT_memory (GMT, NULL, GMT_INITIAL_MEM_ROW_ALLOC, double);
 	GMT->hidden.mem_rows = GMT_INITIAL_MEM_ROW_ALLOC;
+	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "GMT memory: Initialize %" PRIuS " temporary column arrays, each of length : %" PRIuS "\n", GMT->hidden.mem_cols, GMT->hidden.mem_rows);
 }
 
 void GMT_free_tmp_arrays (struct GMT_CTRL *GMT)
@@ -428,7 +429,7 @@ void GMT_free_tmp_arrays (struct GMT_CTRL *GMT)
 	/* Free temporary coordinate memory used by this session */
 	size_t col;
 
-	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "GMT memory: Free %" PRIuS " temporary column arrays, each of length : %" PRIuS "\n", GMT->hidden.mem_cols, GMT->hidden.mem_rows);
+	if (GMT->hidden.mem_cols) GMT_Report (GMT->parent, GMT_MSG_DEBUG, "GMT memory: Free %" PRIuS " temporary column arrays, each of length : %" PRIuS "\n", GMT->hidden.mem_cols, GMT->hidden.mem_rows);
 	for (col = 0; col < GMT->hidden.mem_cols; col++) {	/* For each column, free an array */
 		if (GMT->hidden.mem_coord[col]) GMT_free (GMT, GMT->hidden.mem_coord[col]);
 	}
@@ -462,6 +463,7 @@ void GMT_prep_tmp_arrays (struct GMT_CTRL *GMT, size_t row, size_t n_cols)
 	for (col = 0; col < GMT->hidden.mem_cols; col++)	/* Add more memory via realloc */
 		GMT->hidden.mem_coord[col] = GMT_memory (GMT, GMT->hidden.mem_coord[col], GMT->hidden.mem_rows, double);
 
+	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "GMT memory: Increase %" PRIuS " temporary column arrays to new length : %" PRIuS "\n", GMT->hidden.mem_cols, GMT->hidden.mem_rows);
 	/* Note: Any additions to these arrays are not guaranteed to be set to zero */
 }
 
